@@ -595,6 +595,7 @@ window_create (void)
 		pango_font_description_free (font_desc);
 
 		gtk_container_add (GTK_CONTAINER(vbox), dummy);
+		gtk_widget_show (dummy);
 		gtk_widget_get_preferred_size (dummy, &size_req, NULL);
 		gtk_widget_destroy (dummy);
 		/* ~50 pixels for borders and scrollbar space */
@@ -614,11 +615,15 @@ window_create (void)
 		win_h = win_h + size_req.height + 12;
 	}
 
+	gtk_window_set_position (GTK_WINDOW(window), gx.window_position);
+
 	if (gx.geom_str != NULL) {
 		gtk_widget_show_all (vbox); /* must precede parse_geometry */
 		gtk_window_parse_geometry (GTK_WINDOW(window), gx.geom_str);
 	}
-
+	else {
+		gtk_window_set_default_size (GTK_WINDOW(window), win_w, win_h);
+	}
 
 	/* open the window */
 	gtk_widget_show_all (window);
